[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
emacs-29 f42de74ebea: ; * src/lread.c (read0, skip_lazy_string): Fix com
From: |
Eli Zaretskii |
Subject: |
emacs-29 f42de74ebea: ; * src/lread.c (read0, skip_lazy_string): Fix commentary wording. |
Date: |
Fri, 26 May 2023 05:30:31 -0400 (EDT) |
branch: emacs-29
commit f42de74ebea14de1d8a69d2b79489814ab711883
Author: Eli Zaretskii <eliz@gnu.org>
Commit: Eli Zaretskii <eliz@gnu.org>
; * src/lread.c (read0, skip_lazy_string): Fix commentary wording.
---
src/lread.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/lread.c b/src/lread.c
index 29321263af3..f8ee4e63e23 100644
--- a/src/lread.c
+++ b/src/lread.c
@@ -3401,7 +3401,7 @@ read_bool_vector (Lisp_Object readcharfun)
/* Skip (and optionally remember) a lazily-loaded string
preceded by "#@". Return true if this was a normal skip,
- false if we read #@00 (which skips to EOF). */
+ false if we read #@00 (which skips to EOB). */
static bool
skip_lazy_string (Lisp_Object readcharfun)
{
@@ -3938,7 +3938,7 @@ read0 (Lisp_Object readcharfun, bool locate_syms)
and function definitions that can be loaded lazily. */
if (skip_lazy_string (readcharfun))
goto read_obj;
- obj = Qnil; /* #@00 skips to EOF and yields nil. */
+ obj = Qnil; /* #@00 skips to EOB and yields nil. */
break;
case '$':
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- emacs-29 f42de74ebea: ; * src/lread.c (read0, skip_lazy_string): Fix commentary wording.,
Eli Zaretskii <=